==> nextcloud-app-tasks-0.9.5-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/tasks/l10n/en_GB.js <==
OC.L10N.register(
    "tasks",
    {
    "Tasks" : "Tasks",
    "Due yesterday" : "Due yesterday",
    "Due today" : "Due today",
    "Due tomorrow" : "Due tomorrow",
    "Due on" : "Due on",
    "Started yesterday" : "Started yesterday",
    "Starts today" : "Starts today",
    "Starts tomorrow" : "Starts tomorrow",
    "Started on" : "Started on",
    "Starts on" : "Starts on",
    "[Remind me yesterday at ]HH:mm" : "[Remind me yesterday at ]HH:mm",
    "[Remind me today at ]HH:mm" : "[Remind me today at ]HH:mm",
    "[Remind me tomorrow at ]HH:mm" : "[Remind me tomorrow at ]HH:mm",
    "[Remind me on ]MMM DD, YYYY,[ at ]HH:mm" : "[Remind me on ]DD MMM, YYYY,[ at ]HH:mm",
    "Yesterday" : "Yesterday",
    "Today" : "Today",
    "Tomorrow" : "Tomorrow",
    "in %s" : "in %s",
    "%s ago" : "%s ago",
    "seconds" : "seconds",
    "a minute" : "a minute",
    "%d minutes" : "%d minutes",
    "an hour" : "an hour",
    "%d hours" : "%d hours",
    "a day" : "a day",
    "%d days" : "%d days",
    "a month" : "a month",
    "%d months" : "%d months",
    "a year" : "a year",
    "%d years" : "%d years",
    "week" : "week",
    "weeks" : "weeks",
    "day" : "day",
    "days" : "days",
    "hour" : "hour",
    "hours" : "hours",
    "minute" : "minute",
    "minutes" : "minutes",
    "second" : "second",
    "before beginning" : "before beginning",
    "after beginning" : "after beginning",
    "before end" : "before end",
    "after end" : "after end",
    "Comment" : "Comment",
    "Add a comment" : "Add a comment",
    "This will delete the Calendar \"%s\" and all of its entries." : "This will delete the Calendar \"%s\" and all of its entries.",
    "The name \"%s\" is already used." : "The name \"%s\" is already used.",
    "An empty name is not allowed." : "An empty name is not allowed.",
    "Hidden" : "Hidden",
    "Visible" : "Visible",
    "Automatic" : "Automatic",
    "Sunday" : "Sunday",
    "Monday" : "Monday",
    "Tuesday" : "Tuesday",
    "Wednesday" : "Wednesday",
    "Thursday" : "Thursday",
    "Friday" : "Friday",
    "Saturday" : "Saturday",
    "Add an important item in \"%s\"..." : "Add an important item in \"%s\"...",
    "Add an item due today in \"%s\"..." : "Add an item due today in \"%s\"...",
    "Add an item in \"%s\"..." : "Add an item in \"%s\"...",
    "Add a current item in \"%s\"..." : "Add a current item in \"%s\"...",
    "Add a subtask to \"%s\"..." : "Add a subtask to \"%s\"...",
    "_%n Completed Task_::_%n Completed Tasks_" : ["%n Completed Task","%n Completed Tasks"],
    "Hours" : "Hours",
    "Minutes" : "Minutes",
    "Set due date" : "Set due date",
    "%s %% completed" : "%s %% completed",
    "priority %s: " : "priority %s: ",
    "high" : "high",
    "medium" : "medium",
    "low" : "low",
    "no priority assigned" : "no priority assigned",
    "Remind me" : "Remind me",
    "at the end" : "at the end",
    "at the beginning" : "at the beginning",
    "Set start date" : "Set start date",
    "{calendar} shared by {owner}" : "{calendar} shared by {owner}",
    "Unnamed" : "Unnamed",
    "Important" : "Important",
    "Week" : "Week",
    "All" : "All",
    "Current" : "Current",
    "Completed" : "Completed",
    "Delete" : "Delete",
    "Cancel" : "Cancel",
    "Edit" : "Edit",
    "Link" : "Link",
    "Download" : "Download",
    "Save" : "Save",
    "Add List..." : "Add List...",
    "New List" : "New List",
    "Settings" : "Settings",
    "Start of week" : "Start of week",
    "Visibility of Smart Collections" : "Visibility of Smart Collections",
    "Default" : "Default",
    "Load remaining completed tasks." : "Load remaining completed tasks.",
    "(New category)" : "(New category)",
    "Select categories..." : "Select categories...",
    "Loading the task..." : "Loading the task...",
    "Task not found!" : "Task not found!",
    "add a subtask to" : "add a subtask to"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-app-tasks-0.9.6-2-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/tasks/l10n/en_GB.js <==
OC.L10N.register(
    "tasks",
    {
    "Tasks" : "Tasks",
    "Due yesterday" : "Due yesterday",
    "Due today" : "Due today",
    "Due tomorrow" : "Due tomorrow",
    "Due on" : "Due on",
    "Started yesterday" : "Started yesterday",
    "Starts today" : "Starts today",
    "Starts tomorrow" : "Starts tomorrow",
    "Started on" : "Started on",
    "Starts on" : "Starts on",
    "[Remind me yesterday at ]HH:mm" : "[Remind me yesterday at ]HH:mm",
    "[Remind me today at ]HH:mm" : "[Remind me today at ]HH:mm",
    "[Remind me tomorrow at ]HH:mm" : "[Remind me tomorrow at ]HH:mm",
    "[Remind me on ]MMM DD, YYYY,[ at ]HH:mm" : "[Remind me on ]DD MMM, YYYY,[ at ]HH:mm",
    "Yesterday" : "Yesterday",
    "Today" : "Today",
    "Tomorrow" : "Tomorrow",
    "in %s" : "in %s",
    "%s ago" : "%s ago",
    "seconds" : "seconds",
    "a minute" : "a minute",
    "%d minutes" : "%d minutes",
    "an hour" : "an hour",
    "%d hours" : "%d hours",
    "a day" : "a day",
    "%d days" : "%d days",
    "a month" : "a month",
    "%d months" : "%d months",
    "a year" : "a year",
    "%d years" : "%d years",
    "week" : "week",
    "weeks" : "weeks",
    "day" : "day",
    "days" : "days",
    "hour" : "hour",
    "hours" : "hours",
    "minute" : "minute",
    "minutes" : "minutes",
    "second" : "second",
    "before beginning" : "before beginning",
    "after beginning" : "after beginning",
    "before end" : "before end",
    "after end" : "after end",
    "Comment" : "Comment",
    "Add a comment" : "Add a comment",
    "This will delete the Calendar \"%s\" and all of its entries." : "This will delete the Calendar \"%s\" and all of its entries.",
    "The name \"%s\" is already used." : "The name \"%s\" is already used.",
    "An empty name is not allowed." : "An empty name is not allowed.",
    "Hidden" : "Hidden",
    "Visible" : "Visible",
    "Automatic" : "Automatic",
    "Sunday" : "Sunday",
    "Monday" : "Monday",
    "Tuesday" : "Tuesday",
    "Wednesday" : "Wednesday",
    "Thursday" : "Thursday",
    "Friday" : "Friday",
    "Saturday" : "Saturday",
    "Add an important item in \"%s\"..." : "Add an important item in \"%s\"...",
    "Add an item due today in \"%s\"..." : "Add an item due today in \"%s\"...",
    "Add an item in \"%s\"..." : "Add an item in \"%s\"...",
    "Add a current item in \"%s\"..." : "Add a current item in \"%s\"...",
    "Add a subtask to \"%s\"..." : "Add a subtask to \"%s\"...",
    "_%n Completed Task_::_%n Completed Tasks_" : ["%n Completed Task","%n Completed Tasks"],
    "Hours" : "Hours",
    "Minutes" : "Minutes",
    "Set due date" : "Set due date",
    "%s %% completed" : "%s %% completed",
    "priority %s: " : "priority %s: ",
    "high" : "high",
    "medium" : "medium",
    "low" : "low",
    "no priority assigned" : "no priority assigned",
    "Remind me" : "Remind me",
    "at the end" : "at the end",
    "at the beginning" : "at the beginning",
    "Set start date" : "Set start date",
    "{calendar} shared by {owner}" : "{calendar} shared by {owner}",
    "Unnamed" : "Unnamed",
    "Important" : "Important",
    "Week" : "Week",
    "All" : "All",
    "Current" : "Current",
    "Completed" : "Completed",
    "Delete" : "Delete",
    "Cancel" : "Cancel",
    "Edit" : "Edit",
    "Link" : "Link",
    "Download" : "Download",
    "Save" : "Save",
    "Add List..." : "Add List...",
    "New List" : "New List",
    "Settings" : "Settings",
    "Start of week" : "Start of week",
    "Visibility of Smart Collections" : "Visibility of Smart Collections",
    "Change sort order" : "Change sort order",
    "Default" : "Default",
    "Due date" : "Due date",
    "Start date" : "Start date",
    "Priority" : "Priority",
    "Alphabetically" : "Alphabetically",
    "Manually" : "Manually",
    "Load remaining completed tasks." : "Load remaining completed tasks.",
    "Task is completed" : "Task is completed",
    "All day" : "All day",
    "(New category)" : "(New category)",
    "Select categories..." : "Select categories...",
    "Loading the task..." : "Loading the task...",
    "Task not found!" : "Task not found!",
    "add a subtask to" : "add a subtask to",
    "Toggle subtasks" : "Toggle subtasks",
    "Toggle completed subtasks" : "Toggle completed subtasks"
},
"nplurals=2; plural=(n != 1);");
